package com.poc.controller;

import java.util.List;

import javax.validation.Valid;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import com.poc.entity.Employee;
import com.poc.model.Emp;
import com.poc.service.EmployeeService;

@RestController
@RequestMapping(path = "/employees")
@Validated
public class EmployeeController {
	@Autowired
	private EmployeeService employeeService;

	@GetMapping(produces = "application/json", consumes = "application/json", path = "/empId/{empId}")
	public ResponseEntity<Emp> findByEmpId(@Valid @PathVariable Long empId) {
		return new ResponseEntity<>(employeeService.findByEmpId(empId), HttpStatus.OK);
	}

	@GetMapping(produces = "application/json", consumes = "application/json", path = "/")
	public ResponseEntity<List<Emp>> findAll() {
		return new ResponseEntity<>(employeeService.findAll(), HttpStatus.OK);
	}
	
	@GetMapping(produces = "application/json", consumes = "application/json", path = "/id/{id}")
	public ResponseEntity<Emp> findById(@Valid @PathVariable String id) {
		return new ResponseEntity<>(employeeService.findById(id), HttpStatus.OK);
	}

	@GetMapping(produces = "application/json", consumes = "application/json", path = "/sal/{sal}")
	public ResponseEntity<List<Emp>> findBySal(@Valid @PathVariable Double sal) {
		return new ResponseEntity<>(employeeService.findBySalary(sal), HttpStatus.OK);
	}
	
	@PostMapping(produces = "application/json", consumes = "application/json", path = "/upsert")
	public ResponseEntity<Emp> saveOrUpdateEmployee(@Valid @RequestBody Emp emp) {
		employeeService.saveOrUpdate(emp);
		return new ResponseEntity<>(HttpStatus.OK);
	}
	
	@PostMapping(produces = "application/json", consumes = "application/json", path = "/save")
	public ResponseEntity<Emp> saveEmployee(@Valid @RequestBody Emp emp) {
		return new ResponseEntity<>(employeeService.save(emp), HttpStatus.OK);
	}

	@DeleteMapping(produces = "application/json", consumes = "application/json", path = "/delete/{empId}")
	public ResponseEntity<Long> deleteByEmpId(@PathVariable Long empId) {
		return new ResponseEntity<>(employeeService.deleteByEmpId(empId), HttpStatus.OK);
	}
}
